@@ -116,7 +116,7 @@ struct MockNetProviderInner {
 pub struct MockNetListener {
     /// The address that we're listening on.
     addr: SocketAddr,
-    /// The incoming channnnel that tells us about new connections.
+    /// The incoming channel that tells us about new connections.
     // TODO: I'm not thrilled to have to use an AsyncMutex and a
     // std Mutex in the same module.
     receiver: AsyncMutex<ConnReceiver>,
@@ -174,7 +174,7 @@ impl MockNetwork {
         want_tls: bool,
     ) -> IoResult<Option<Vec<u8>>> {
         let entry = {
-            let listener_map = self.listening.lock().unwrap();
+            let listener_map = self.listening.lock().expect("Poisoned lock for listener");
             listener_map.get(&target_addr).map(Clone::clone)
         };
         if let Some(mut entry) = entry {
@@ -196,9 +196,9 @@ impl MockNetwork {
     /// If tls_cert is provided, then the listener is a TLS listener
     /// and any only TLS connection attempts should succeed.
     ///
-    /// Returns an error if the address is alrady in use.
+    /// Returns an error if the address is already in use.
     fn add_listener(&self, addr: SocketAddr, tls_cert: Option<Vec<u8>>) -> IoResult<ConnReceiver> {
-        let mut listener_map = self.listening.lock().unwrap();
+        let mut listener_map = self.listening.lock().expect("Poisoned lock for listener");
         if listener_map.contains_key(&addr) {
             // TODO: Maybe this should ignore dangling Weak references?
             return Err(err(ErrorKind::AddrInUse));
@@ -215,7 +215,7 @@ impl MockNetwork {
 }
 
 impl ProviderBuilder {
-    /// Add `addr` as a new address for the prrovider we're building.
+    /// Add `addr` as a new address for the provider we're building.
     pub fn add_address(&mut self, addr: IpAddr) -> &mut Self {
         self.addrs.push(addr);
         self
@@ -289,7 +289,8 @@ impl MockNetProvider {
     ///
     /// # Panics
     ///
-    /// We panic if we run out of unused port numbers here.
+    /// Panics if there are no remaining ports that this function hasn't
+    /// returned before.
     fn arbitrary_port(&self) -> u16 {
         let next = self.inner.next_port.fetch_add(1, Ordering::Relaxed);
         assert!(next != 0);
@@ -492,9 +493,10 @@ fn err(k: ErrorKind) -> IoError {
 
 #[cfg(test)]
 mod test {
+    #![allow(clippy::unwrap_used)]
     use super::*;
     use futures::io::{AsyncReadExt, AsyncWriteExt};
-    use tor_rtcompat::test_with_runtime;
+    use tor_rtcompat::test_with_all_runtimes;
 
     fn client_pair() -> (MockNetProvider, MockNetProvider) {
         let net = MockNetwork::new();
@@ -512,9 +514,8 @@ mod test {
 
     #[test]
     fn end_to_end() -> IoResult<()> {
-        let (client1, client2) = client_pair();
-
-        test_with_runtime(|_rt| async {
+        test_with_all_runtimes!(|_rt| async {
+            let (client1, client2) = client_pair();
             let lis = client2.listen(&"0.0.0.0:99".parse().unwrap()).await?;
             let address = lis.local_addr()?;
 
@@ -541,7 +542,7 @@ mod test {
             );
             r1?;
             r2?;
-            Ok(())
+            IoResult::Ok(())
         })
     }
 
@@ -579,14 +580,14 @@ mod test {
         assert!(e1.is_err());
         assert!(e2.is_err());
 
-        Ok(())
+        IoResult::Ok(())
     }
 
     #[test]
     fn listener_stream() -> IoResult<()> {
-        let (client1, client2) = client_pair();
+        test_with_all_runtimes!(|_rt| async {
+            let (client1, client2) = client_pair();
 
-        test_with_runtime(|_rt| async {
             let lis = client2.listen(&"0.0.0.0:99".parse().unwrap()).await?;
             let address = lis.local_addr()?;
             let mut incoming = lis.incoming();
@@ -611,7 +612,7 @@ mod test {
             );
             r1?;
             r2?;
-            Ok(())
+            IoResult::Ok(())
         })
     }
 
@@ -623,7 +624,7 @@ mod test {
         let lis = client2.listen_tls(&"0.0.0.0:0".parse().unwrap(), cert[..].into())?;
         let address = lis.local_addr()?;
 
-        test_with_runtime(|_rt| async {
+        test_with_all_runtimes!(|_rt| async {
             let (r1, r2): (IoResult<()>, IoResult<()>) = futures::join!(
                 async {
                     let connector = client1.tls_connector();
@@ -654,7 +655,7 @@ mod test {
             );
             r1?;
             r2?;
-            Ok(())
+            IoResult::Ok(())
         })
     }
 }
